@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: esqueleto
 version: 2.4.3
-id: esqueleto-2.4.3-bcf3326df4198d186e960a7b03fcb9e6
-key: esque_Hl9CKeaOM7B534wB9kzsbW
+id: esqueleto-2.4.3-d3f7fac89495c2a2de6f99ff3c145caa
+key: esque_J4UKviL5vns2XKFt7M40ps
 license: BSD3
 copyright: (c) 2012-2015 Felipe Almeida Lessa
 maintainer: felipe.lessa@gmail.com
@@ -52,14 +52,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/esqueleto-2.4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/esqueleto-2.4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/esqueleto-2.4.3
-hs-libraries: HSesqueleto-2.4.3-Hl9CKeaOM7B534wB9kzsbW
+hs-libraries: HSesqueleto-2.4.3-J4UKviL5vns2XKFt7M40ps
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    monad-logger-0.3.18-77245c726e2e1fb18d9b7ba72ab04e41
-    persistent-2.2.4.1-f7f5136d623755022a88522f150cf471
+    monad-logger-0.3.18-e41795701bd26d2e948311dc59f0bce2
+    persistent-2.2.4.1-515160ea71a89b76b70a56c63b058aa3
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
